function  S_plot_Points(ncl,xcl,ycl,zcl,nv1,nv2)
% subroutine S_plot_Points to draw the geometry of 
% a cluster with one particle as center
% The input parameters are:
% ncl : numbers of particles
% xcl, ycl, zcl: arrays of numbers corresponding to the 3D
% cluster's coordinates
% nv1, nv2 : integer number to determine the shells to draw
% With nv1=0 and nv2=2, the cluster's nucleo and the first shell
% are depicted
% ====================================================================
% More information of this subroutine is in the article:
% Discrete Optimal Global Congergence of a Novel Evolutionary Algorith
% for Clusters under Lennard JOnes Potential
% Author: Carlos Barron Romero
% Universidad Autonoma Metropolitana, campus Azcapotzalco
% Mexico City.
% This subroutine can be freely used, distributed or modified under 
% your own responsability.
% ====================================================================
%
% Arrays for particle's neighboors and number of neighboors
vec=zeros(ncl,12);
nvc=zeros(ncl,1);
% dmg is the optimal distance of a pair of particles under 
% Lennard Jones Potential
dmg=1.0; % Normalizado
% 10% is the factor to define the lower and upper limits
% for acepting a particle's neighboor
tol=0.3;
d_inf = dmg * (1 - tol);
d_sup = dmg * (1 + tol);
%
% This loop determines the particle's neighboor
for i=1:ncl-1
    for j=i+1:ncl
        dij=norm([(xcl(i)-xcl(j)),(ycl(i)-ycl(j)),(zcl(i)-zcl(j))]);
        if ((d_inf < dij) && (dij < d_sup))
            nvc(i)=nvc(i)+1;
            vec(i,nvc(i))=j;
            nvc(j)=nvc(j)+1;
            vec(j,nvc(j))=i;
        end
    end
end
%
% for selecting a particle closed to (0,0,0) as a nucleo 
ra = 999.99;
pnuc=zeros(13,1);
nnuc=0;
fnuc = 0;
for i=1:ncl
    dcl=norm([xcl(i),ycl(i),zcl(i)]);
    if (dcl < ra)
        ra = dcl;
        nnuc=1;
        pnuc(nnuc)=i;
    end
end
% Such particle is closed to (0,0,0)
% With a nucleo, is is possible to determine the cluster's shells
capa=zeros(ncl,1);
ncapa=1;
Queue(ncl);
for jp=1:nnuc
    capa(pnuc(jp))=1;
    Enqueue(pnuc(jp));
end
while (~(IsEmptyqueue))
    ui = Headqueue;
    for jv=1:nvc(ui)
        pvc=vec(ui,jv);
        if (capa(pvc)== 0)
            capa(pvc) = capa(ui) + 1;
            Enqueue(pvc);
        end
    end
    Dequeue;
end
% Color table
tclr = [ 1,0,0; ...
    0,1,0; ...
    0,0,1; ...
    1,1,0; ... 
    51/255, 153/255, 1; ...
    1,0,1; ... 
    0.5,0.5,1; ... 
    0.5,0.5,0.5; ...
    1,0.5,1; ...
    1,0.5,0.5; ...
    1,0.5,0.75; ...
    1,0.75,0; ...
    0,0,0];
hold on;
for i=1:ncl
    if (capa(i) < nv1)
        continue;
    end
    if (capa(i) > nv2)
        continue;
    end
    % cluster's lines
    for jv=1:nvc(i)
        pvc=vec(i,jv);
        if (capa(i) == capa (pvc))
            line([xcl(i),xcl(pvc)], ...
                [ycl(i),ycl(pvc)], ...
                [zcl(i),zcl(pvc)], ...
                'Color',tclr(capa(i),:), ...
                'LineWidth',1);

        end
    end
    % particles
    plot3(xcl(i), ...
        ycl(i), ...
        zcl(i), '-ko',...
        'LineWidth',1,...
        'MarkerEdgeColor','k', ...
        'MarkerFaceColor',tclr(capa(i),:),...
        'MarkerSize',8);
end
axis equal;
grid on;
linp=sprintf('Cluster of %d particles',ncl);
title(linp);
view(45,45);
hold off;
